@@ -16,12 +16,13 @@ pub struct RedisType {
 unsafe impl Sync for RedisType {}
 
 impl RedisType {
+    #[must_use]
     pub const fn new(
         name: &'static str,
         version: i32,
         type_methods: raw::RedisModuleTypeMethods,
     ) -> Self {
-        RedisType {
+        Self {
             name,
             version,
             type_methods,
