@@ -49,7 +49,7 @@ pub enum KeyType {
 
 impl From<c_int> for KeyType {
     fn from(v: c_int) -> Self {
-        KeyType::from_i32(v).unwrap()
+        Self::from_i32(v).unwrap()
     }
 }
 
@@ -71,7 +71,7 @@ pub enum ReplyType {
 
 impl From<c_int> for ReplyType {
     fn from(v: c_int) -> Self {
-        ReplyType::from_i32(v).unwrap()
+        Self::from_i32(v).unwrap()
     }
 }
 
@@ -89,7 +89,7 @@ pub enum Status {
 
 impl From<c_int> for Status {
     fn from(v: c_int) -> Self {
-        Status::from_i32(v).unwrap()
+        Self::from_i32(v).unwrap()
     }
 }
 
@@ -578,24 +578,15 @@ pub fn register_info_function(ctx: *mut RedisModuleCtx, callback: RedisModuleInf
 }
 
 #[allow(clippy::not_unsafe_ptr_arg_deref)]
-pub fn add_info_section(
-    ctx: *mut RedisModuleInfoCtx,
-    name: Option<&str>, // assume NULL terminated
-) -> Status {
-    let name = name.map(|n| CString::new(n).unwrap());
-    if let Some(n) = name {
-        unsafe { RedisModule_InfoAddSection.unwrap()(ctx, n.as_ptr() as *mut c_char).into() }
-    } else {
-        unsafe { RedisModule_InfoAddSection.unwrap()(ctx, ptr::null_mut()).into() }
-    }
+pub fn add_info_section(ctx: *mut RedisModuleInfoCtx, name: Option<&str>) -> Status {
+    name.map(|n| CString::new(n).unwrap()).map_or_else(
+        || unsafe { RedisModule_InfoAddSection.unwrap()(ctx, ptr::null_mut()).into() },
+        |n| unsafe { RedisModule_InfoAddSection.unwrap()(ctx, n.as_ptr() as *mut c_char).into() },
+    )
 }
 
 #[allow(clippy::not_unsafe_ptr_arg_deref)]
-pub fn add_info_field_str(
-    ctx: *mut RedisModuleInfoCtx,
-    name: &str, // assume NULL terminated
-    content: &str,
-) -> Status {
+pub fn add_info_field_str(ctx: *mut RedisModuleInfoCtx, name: &str, content: &str) -> Status {
     let name = CString::new(name).unwrap();
     let content = RedisString::create(ptr::null_mut(), content);
     unsafe {
@@ -607,7 +598,7 @@ pub fn add_info_field_str(
 #[allow(clippy::not_unsafe_ptr_arg_deref)]
 pub fn add_info_field_long_long(
     ctx: *mut RedisModuleInfoCtx,
-    name: &str, // assume NULL terminated
+    name: &str,
     value: c_longlong,
 ) -> Status {
     let name = CString::new(name).unwrap();
@@ -616,35 +607,31 @@ pub fn add_info_field_long_long(
     }
 }
 
+/// # Safety
 #[cfg(feature = "experimental-api")]
-pub fn export_shared_api(
+pub unsafe fn export_shared_api(
     ctx: *mut RedisModuleCtx,
     func: *const ::std::os::raw::c_void,
     name: *const ::std::os::raw::c_char,
 ) {
-    unsafe { RedisModule_ExportSharedAPI.unwrap()(ctx, name, func as *mut ::std::os::raw::c_void) };
+    RedisModule_ExportSharedAPI.unwrap()(ctx, name, func as *mut ::std::os::raw::c_void);
 }
 
+/// # Safety
 #[cfg(feature = "experimental-api")]
-pub fn notify_keyspace_event(
+pub unsafe fn notify_keyspace_event(
     ctx: *mut RedisModuleCtx,
     event_type: NotifyEvent,
     event: &str,
     keyname: &RedisString,
 ) -> Status {
     let event = CString::new(event).unwrap();
-    unsafe {
-        RedisModule_NotifyKeyspaceEvent.unwrap()(
-            ctx,
-            event_type.bits,
-            event.as_ptr(),
-            keyname.inner,
-        )
+    RedisModule_NotifyKeyspaceEvent.unwrap()(ctx, event_type.bits, event.as_ptr(), keyname.inner)
         .into()
-    }
 }
 
 #[cfg(feature = "experimental-api")]
+#[must_use]
 pub fn get_keyspace_events() -> NotifyEvent {
     unsafe {
         let events = RedisModule_GetNotifyKeyspaceEvents.unwrap()();
@@ -652,6 +639,24 @@ pub fn get_keyspace_events() -> NotifyEvent {
     }
 }
 
+#[derive(Debug, PartialEq)]
+pub struct Version {
+    pub major: i32,
+    pub minor: i32,
+    pub patch: i32,
+}
+
+impl From<c_int> for Version {
+    fn from(ver: c_int) -> Self {
+        // Expected format: 0x00MMmmpp for Major, minor, patch
+        Self {
+            major: (ver & 0x00FF_0000) >> 16,
+            minor: (ver & 0x0000_FF00) >> 8,
+            patch: (ver & 0x0000_00FF),
+        }
+    }
+}
+
 #[allow(clippy::not_unsafe_ptr_arg_deref)]
 pub fn is_io_error(rdb: *mut RedisModuleIO) -> bool {
     unsafe { RedisModule_IsIOError.unwrap()(rdb) != 0 }
