@@ -11,18 +11,20 @@ pub enum RedisError {
 }
 
 impl RedisError {
+    #[must_use]
     pub fn nonexistent_key() -> Self {
-        RedisError::Str("ERR could not perform this operation on a key that doesn't exist")
+        Self::Str("ERR could not perform this operation on a key that doesn't exist")
     }
 
+    #[must_use]
     pub fn short_read() -> Self {
-        RedisError::Str("ERR short read or OOM loading DB")
+        Self::Str("ERR short read or OOM loading DB")
     }
 }
 
 impl<T: std::error::Error> From<T> for RedisError {
     fn from(e: T) -> Self {
-        RedisError::String(format!("ERR {}", e))
+        Self::String(format!("ERR {}", e))
     }
 }
 
