@@ -3,6 +3,8 @@
 #![allow(non_snake_case)]
 #![allow(dead_code)]
 
+// Workaround for https://github.com/rust-lang/rust-bindgen/issues/1651#issuecomment-848479168
+#[allow(deref_nullptr)]
 pub mod bindings {
     include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
 }
